bayespy.inference.vmp.nodes.bernoulli.BernoulliMoments
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. autoclass:: BernoulliMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~BernoulliMoments.__init__
      ~BernoulliMoments.add_converter
      ~BernoulliMoments.compute_dims_from_values
      ~BernoulliMoments.compute_fixed_moments
      ~BernoulliMoments.get_converter
   
   

   
   
   